@@ -14,7 +14,7 @@
 #' @return A tibble with the StatCan table data
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # Retrieve a table with an NDM code
 #' get_cansim("34-10-0013")
 #' # Retrieve a table with an old-style CANSIM code
@@ -44,7 +44,7 @@ get_cansim_ndm <- function(cansimTableNumber, language="english", refresh=FALSE,
 #' @return Returns the input tibble with with adjusted values
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' cansim_table <- get_cansim("34-10-0013")
 #' normalize_cansim_values(cansim_table)
 #' }
@@ -141,48 +141,61 @@ normalize_cansim_values <- function(data, replacement_value=NA, normalize_percen
     #     mutate(!!field:=factor(!!as.name(field),levels=levels_for_field(field)))
     # }
     for (field in fields) {
-      hierarchy_field <- paste0(hierarchy_prefix,field)
-      parent_field <- paste0("parent ",field)
-      levels_data <- data %>%
-        select(all_of(c(field,hierarchy_field))) %>%
-        unique %>%
-        rename(...name = !!as.name(field)) %>%
-        mutate(...dupes=.data$...name %in% filter(.,duplicated(.data$...name))$...name) %>%
-        mutate(...parent_hierarchy=parent_hierarchy(pull(.,hierarchy_field)))
-
-      while (sum(levels_data$...dupes)>0 && nrow(filter(levels_data,.data$...parent_hierarchy!=""))>0) {
-        levels_data <- levels_data %>%
-          mutate(...parent_hierarchy=parent_hierarchy(pull(.,hierarchy_field))) %>%
-          left_join(select(.,all_of(c("...name",hierarchy_field)))%>%
-                      rename(!!!rlang::set_names("...name",parent_field)),
-                    by=c(...parent_hierarchy=hierarchy_field)) %>%
-          mutate(...name=ifelse(.data$...dupes,
-                                paste0(.data$...name," (",!!as.name(parent_field),")"),
-                                .data$...name)) %>%
+      tryCatch({
+        hierarchy_field <- paste0(hierarchy_prefix,field)
+        parent_field <- paste0("parent ",field)
+        levels_data <- data %>%
+          select(all_of(c(field,hierarchy_field))) %>%
+          unique %>%
+          rename(...name = !!as.name(field)) %>%
           mutate(...dupes=.data$...name %in% filter(.,duplicated(.data$...name))$...name) %>%
-          mutate(...parent_hierarchy=parent_hierarchy(.data$...parent_hierarchy))
-      }
-      if (sum(levels_data$...dupes)>0) {
+          mutate(...parent_hierarchy=parent_hierarchy(pull(.,hierarchy_field))) %>%
+          mutate(...original_name = .data$...name)
+
+        max_iterations <- 20 # failsafe
+        while (nrow(levels_data %>%filter(.data$...dupes,.data$...parent_hierarchy!=""))>0 & max_iterations > 0) {
+          levels_data <- levels_data %>%
+            mutate(...parent_hierarchy=parent_hierarchy(pull(.,hierarchy_field))) %>%
+            select(setdiff(names(.),parent_field)) %>%
+            left_join(select(.,all_of(c("...name",hierarchy_field)))%>%
+                        rename(!!!rlang::set_names("...name",parent_field)),
+                      by=c(...parent_hierarchy=hierarchy_field)) %>%
+            mutate(...name=ifelse(.data$...dupes,
+                                  paste0(.data$...original_name," (",!!as.name(parent_field),")"),
+                                  .data$...name)) %>%
+            mutate(...dupes=.data$...name %in% filter(.,duplicated(.data$...name))$...name) %>%
+            mutate(...parent_hierarchy=parent_hierarchy(.data$...parent_hierarchy))
+          max_iterations <- max_iterations -1
+        }
+        if (max_iterations == 0) warning(paste0("Maximum iterations reached for field ",field,"."))
+        if (sum(levels_data$...dupes)>0) {
+          levels_data <- levels_data %>%
+            group_by(.data$...name) %>%
+            mutate(n=n(),nn=row_number()) %>%
+            mutate(...name=ifelse(n>1,paste0(.data$...name," - ",.data$nn),.data$...name))
+        }
+
+        # make sure order of factors is right
         levels_data <- levels_data %>%
-          group_by(.data$...name) %>%
-          mutate(n=n(),nn=row_number()) %>%
-          mutate(...name=ifelse(n>1,paste0(.data$...name," - ",.data$nn),.data$...name))
-      }
-
-      # make sure order of factors is right
-      levels_data <- levels_data %>%
-        mutate(...h=hierarchy_order(!!as.name(hierarchy_field))) %>%
-        arrange(.data$...h)
+          mutate(...h=hierarchy_order(!!as.name(hierarchy_field))) %>%
+          arrange(.data$...h)
 
 
-      data <- data %>%
-        select(-all_of(field)) %>%
-        left_join(levels_data %>%
-                    select(all_of(c(hierarchy_field,"...name"))) %>%
-                    rename(!!!rlang::set_names("...name",field)),by=hierarchy_field)
+        data <- data %>%
+          select(-all_of(field)) %>%
+          left_join(levels_data %>%
+                      select(all_of(c(hierarchy_field,"...name"))) %>%
+                      rename(!!!rlang::set_names("...name",field)),by=hierarchy_field)
 
-      data <- data %>%
-        mutate_at(field,function(d)factor(d,levels=levels_data$...name))
+        data <- data %>%
+          mutate_at(field,function(d)factor(d,levels=levels_data$...name))
+      },
+      error=function(cond){
+        warning(paste0("Could not convert field ",field, " to a factor, please flag this as an issue in the {cansim} repository at https://github.com/mountainMath/cansim/issues."))
+      },
+      warning=function(cond) {
+        warning(paste0("Encountered a warning when converting field ",field, " to a factor, please flag this as an issue in the {cansim} repository at https://github.com/mountainMath/cansim/issues."))
+      })
     }
   }
 
@@ -198,7 +211,7 @@ normalize_cansim_values <- function(data, replacement_value=NA, normalize_percen
 #' @return A character string with the new-format NDM table number
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' cansim_old_to_new("026-0018")
 #' }
 #' @export
@@ -551,7 +564,7 @@ parse_and_fold_in_metadata <- function(data,meta,data_path){
 #' added \code{val_norm} column with normalized value from the \code{VALUE} column.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim("34-10-0013")
 #' }
 #' @export
@@ -634,7 +647,7 @@ get_cansim <- function(cansimTableNumber, language="english", refresh=FALSE, tim
 #' @return A tibble with the table overview information
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_info("34-10-0013")
 #' }
 #' @export
@@ -660,7 +673,7 @@ get_cansim_table_info <- function(cansimTableNumber, language="english", refresh
 #' @return A tibble with the table survey code and name
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_survey("34-10-0013")
 #' }
 #' @export
@@ -685,7 +698,7 @@ get_cansim_table_survey <- function(cansimTableNumber, language="english", refre
 #' @return A tibble with the table subject code and name.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_subject("34-10-0013")
 #' }
 #' @export
@@ -710,7 +723,7 @@ get_cansim_table_subject <- function(cansimTableNumber, language="english", refr
 #' @return A tibble with the StatCan Notes for the table
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_short_notes("34-10-0013")
 #' }
 #' @export
@@ -735,7 +748,7 @@ get_cansim_table_short_notes <- function(cansimTableNumber, language="english",
 #' @return A tibble listing the column names of the StatCan table.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_column_list("34-10-0013")
 #' }
 #' @export
@@ -761,7 +774,7 @@ get_cansim_column_list <- function(cansimTableNumber, language="english", refres
 #' @return A tibble with detailed information on StatCan table categories for the specified field
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_column_categories("34-10-0013", "Geography")
 #' }
 #' @export
@@ -788,7 +801,7 @@ get_cansim_column_categories <- function(cansimTableNumber, column, language="en
 #' @return none
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_overview("34-10-0013")
 #' }
 #' @export
@@ -833,7 +846,7 @@ get_cansim_table_overview <- function(cansimTableNumber, language="english", ref
 #' @return A vector of categories
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' data <- get_cansim("16-10-0117")
 #' categories_for_level(data,"North American Industry Classification System (NAICS)",level=2)
 #' }
@@ -928,7 +941,7 @@ generate_table_metadata <- function(){
 #' @return none
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' view_cansim_webpage("34-10-0013")
 #' }
 #' @export
@@ -954,7 +967,7 @@ view_cansim_webpage <- function(cansimTableNumber = NULL){
 #' @return a tibble containing the table metadata
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_cube_metadata("34-10-0013")
 #' }
 #' @export
@@ -1008,7 +1021,7 @@ get_cansim_cube_metadata <- function(cansimTableNumber){
 #' @return String object containing URL for specified table number
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_url("34-10-0013")
 #' get_cansim_table_url("34-10-0013", language = "fr")
 #' }
@@ -1034,7 +1047,7 @@ get_cansim_table_url <- function(cansimTableNumber, language = "en"){
 #' @return A tibble with Statistics Canada data table product ids and their release times
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_changed_tables("2018-08-01")
 #' }
 #' @export
@@ -1087,7 +1100,7 @@ get_cansim_changed_tables <- function(start_date,end_date=NULL){
 #' @return A tibble with table notes.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_notes("34-10-0013")
 #' }
 #' @export
@@ -1125,7 +1138,7 @@ get_cansim_table_notes <- function(cansimTableNumber,language="en",refresh=FALSE
 #' @return A datatime object if a release data is available, NULL otherwise.
 #'
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' get_cansim_table_last_release_date("34-10-0013")
 #' }
 #' @export
